# EvCore

Base plugin for all Evoluted New Media CakePHP based websites.

## Features

### User Management

#### Google reCAPTCHA

In a bid to tackle User Enumeration attacks, Google reCAPTCHA support is available on login and registration forms. Below you will find an example implementation. Use of Google reCAPTCHA on login and registration forms is controlled through the EvCore config file (`EvCore/Config/config.php`). As default `userReCaptcha` is set to `false` and does not automatically run out of the box. Set `EvCore.userReCaptcha.login` or `EvCore.userReCaptcha.register` to `false` to use one of the two implementations available.

	<?php
		$config = [
			'EvCore' => [
				...
				// define project specific Google reCAPTCHA details below. reCAPTCHA elements
				// will automatically show on login and registration forms when login or
				// registration interactions fail by the number of allowed attempts defined
				'userReCaptcha' => [
					// replace with site specific secret
					'secret' => '', 

					// replace with site specific siteKey
					'siteKey' => '', 
					
					// the total number of failed login attempts before reCAPTCHA displays
					'showAfterFailedLoginAttempts' => 5,

					// the total number of failed registration attempts before reCAPTCHA displays
					'showAfterFailedRegisterAttempts' => 5,
				],
				...
			],
		];
		
Site specific Google reCAPTCHA keys can be obtained from [https://www.google.com/recaptcha/admin#list](https://www.google.com/recaptcha/admin#list)

A note to bear in mind when adding the functionality to existing sites, you will need to add the reCAPTCHA form element manually (see snippet below).
			
	if (isset($showReCaptcha) && $showReCaptcha === true):
        echo $this->Form->recaptcha('User.g-recaptcha-response', [
            'data-sitekey' => Configure::read('EvCore.userReCaptcha.siteKey')
        ]);
    endif;
			
				